@@ -1,4 +1,5 @@
 """CLI function for a vehicle."""
+import json
 from typing import Any
 from typing import Dict
 from typing import List
@@ -153,13 +154,16 @@ async def display_status(
     vehicle = await get_vehicle(websession, ctx_data)
     status_table: Dict[str, Any] = {}
 
-    await update_battery_status(vehicle, status_table)
-    await update_charge_mode(vehicle, status_table)
-    await update_cockpit(vehicle, status_table)
-    await update_location(vehicle, status_table)
-    await update_lock_status(vehicle, status_table)
-    await update_res_state(vehicle, status_table)
-    await update_hvac_status(vehicle, status_table)
+    await update_battery_status(vehicle, status_table, ctx_data)
+    await update_charge_mode(vehicle, status_table, ctx_data)
+    await update_cockpit(vehicle, status_table, ctx_data)
+    await update_location(vehicle, status_table, ctx_data)
+    await update_lock_status(vehicle, status_table, ctx_data)
+    await update_res_state(vehicle, status_table, ctx_data)
+    await update_hvac_status(vehicle, status_table, ctx_data)
+    if ctx_data["json"]:
+        click.echo(json.dumps(status_table))
+        return
 
     click.echo(tabulate(status_table.items()))
 
@@ -177,7 +181,7 @@ def update_status_table(
 
 
 async def update_battery_status(
-    vehicle: RenaultVehicle, status_table: Dict[str, Any]
+    vehicle: RenaultVehicle, status_table: Dict[str, Any], ctx_data: Dict[str, Any]
 ) -> None:
     """Update status table from get_vehicle_battery_status."""
     try:
@@ -185,41 +189,40 @@ async def update_battery_status(
             return
         if not await vehicle.supports_endpoint("battery-status"):  # pragma: no cover
             return
-        if not await vehicle.has_contract_for_endpoint(
-            "battery-status"
-        ):  # pragma: no cover
-            update_status_table(status_table, "Battery status", "No contract.", None)
-            return
         response = await vehicle.get_battery_status()
     except QuotaLimitException as exc:  # pragma: no cover
         raise click.ClickException(repr(exc)) from exc
     except KamereonResponseException as exc:  # pragma: no cover
         click.echo(f"battery-status: {exc.error_details}", err=True)
-    else:
-        if response.batteryAvailableEnergy == 0:  # pragma: no branch
-            response.batteryAvailableEnergy = None
-        if (  # pragma: no branch
-            response.chargingStatus == -1.0 and response.plugStatus == 0
-        ):
-            response.chargingStatus = 0.0
+        return
 
-        items = [
-            ("Battery level", response.batteryLevel, "%"),
-            ("Last updated", response.timestamp, "tzdatetime"),
-            ("Available energy", response.batteryAvailableEnergy, "kWh"),
-            ("Range estimate", response.batteryAutonomy, "km"),
-            ("Plug state", response.get_plug_status(), None),
-            ("Charging state", response.get_charging_status(), None),
-            ("Charge rate", response.chargingInstantaneousPower, "kW"),
-            ("Time remaining", response.chargingRemainingTime, "min"),
-        ]
+    if response.batteryAvailableEnergy == 0:  # pragma: no branch
+        response.batteryAvailableEnergy = None
+    if (  # pragma: no branch
+        response.chargingStatus == -1.0 and response.plugStatus == 0
+    ):
+        response.chargingStatus = 0.0
 
-        for key, value, unit in items:
-            update_status_table(status_table, key, value, unit)
+    if ctx_data["json"]:
+        status_table["battery-status"] = response.raw_data
+        return
+    items = [
+        ("Battery level", response.batteryLevel, "%"),
+        ("Last updated", response.timestamp, "tzdatetime"),
+        ("Available energy", response.batteryAvailableEnergy, "kWh"),
+        ("Range estimate", response.batteryAutonomy, "km"),
+        ("Plug state", response.get_plug_status(), None),
+        ("Charging state", response.get_charging_status(), None),
+        ("Charge rate", response.chargingInstantaneousPower, "kW"),
+        ("Time remaining", response.chargingRemainingTime, "min"),
+    ]
+
+    for key, value, unit in items:
+        update_status_table(status_table, key, value, unit)
 
 
 async def update_charge_mode(
-    vehicle: RenaultVehicle, status_table: Dict[str, Any]
+    vehicle: RenaultVehicle, status_table: Dict[str, Any], ctx_data: Dict[str, Any]
 ) -> None:
     """Update status table from get_vehicle_charge_mode."""
     try:
@@ -227,75 +230,78 @@ async def update_charge_mode(
             return
         if not await vehicle.supports_endpoint("charge-mode"):  # pragma: no cover
             return
-        if not await vehicle.has_contract_for_endpoint(
-            "charge-mode"
-        ):  # pragma: no cover
-            update_status_table(status_table, "Charge mode", "No contract.", None)
-            return
         response = await vehicle.get_charge_mode()
     except QuotaLimitException as exc:  # pragma: no cover
         raise click.ClickException(repr(exc)) from exc
     except KamereonResponseException as exc:  # pragma: no cover
         click.echo(f"charge-mode: {exc.error_details}", err=True)
-    else:
-        items = [("Charge mode", response.chargeMode, None)]
+        return
 
-        for key, value, unit in items:
-            update_status_table(status_table, key, value, unit)
+    if ctx_data["json"]:
+        status_table["charge-mode"] = response.raw_data
+        return
+    items = [("Charge mode", response.chargeMode, None)]
+
+    for key, value, unit in items:
+        update_status_table(status_table, key, value, unit)
 
 
-async def update_cockpit(vehicle: RenaultVehicle, status_table: Dict[str, Any]) -> None:
+async def update_cockpit(
+    vehicle: RenaultVehicle, status_table: Dict[str, Any], ctx_data: Dict[str, Any]
+) -> None:
     """Update status table from get_vehicle_cockpit."""
     try:
         if not await vehicle.supports_endpoint("cockpit"):  # pragma: no cover
             return
-        if not await vehicle.has_contract_for_endpoint("cockpit"):  # pragma: no cover
-            update_status_table(status_table, "Cockpit", "No contract.", None)
-            return
         response = await vehicle.get_cockpit()
     except QuotaLimitException as exc:  # pragma: no cover
         raise click.ClickException(repr(exc)) from exc
     except KamereonResponseException as exc:  # pragma: no cover
         click.echo(f"cockpit: {exc.error_details}", err=True)
-    else:
-        items = [
-            ("Total mileage", response.totalMileage, "km"),
-            ("Fuel autonomy", response.fuelAutonomy, "km"),
-            ("Fuel quantity", response.fuelQuantity, "L"),
-        ]
+        return
 
-        for key, value, unit in items:
-            update_status_table(status_table, key, value, unit)
+    if ctx_data["json"]:
+        status_table["cockpit"] = response.raw_data
+        return
+    items = [
+        ("Total mileage", response.totalMileage, "km"),
+        ("Fuel autonomy", response.fuelAutonomy, "km"),
+        ("Fuel quantity", response.fuelQuantity, "L"),
+    ]
+
+    for key, value, unit in items:
+        update_status_table(status_table, key, value, unit)
 
 
 async def update_location(
-    vehicle: RenaultVehicle, status_table: Dict[str, Any]
+    vehicle: RenaultVehicle, status_table: Dict[str, Any], ctx_data: Dict[str, Any]
 ) -> None:
     """Update status table from get_vehicle_location."""
     try:
         if not await vehicle.supports_endpoint("location"):
             return
-        if not await vehicle.has_contract_for_endpoint("location"):  # pragma: no cover
-            update_status_table(status_table, "Location", "No contract.", None)
-            return
         response = await vehicle.get_location()
     except QuotaLimitException as exc:  # pragma: no cover
         raise click.ClickException(repr(exc)) from exc
     except KamereonResponseException as exc:  # pragma: no cover
         click.echo(f"location: {exc.error_details}", err=True)
-    else:
-        items = [
-            ("GPS Latitude", response.gpsLatitude, None),
-            ("GPS Longitude", response.gpsLongitude, None),
-            ("GPS last updated", response.lastUpdateTime, "tzdatetime"),
-        ]
+        return
 
-        for key, value, unit in items:
-            update_status_table(status_table, key, value, unit)
+    if ctx_data["json"]:  # pragma: no cover
+        status_table["location"] = response.raw_data
+        return
+    items = [
+        ("GPS Latitude", response.gpsLatitude, None),
+        ("GPS Longitude", response.gpsLongitude, None),
+        ("GPS last updated", response.lastUpdateTime, "tzdatetime"),
+    ]
+
+    for key, value, unit in items:
+        update_status_table(status_table, key, value, unit)
 
 
 async def update_lock_status(
-    vehicle: RenaultVehicle, status_table: Dict[str, Any]
+    vehicle: RenaultVehicle, status_table: Dict[str, Any], ctx_data: Dict[str, Any]
 ) -> None:
     """Update status table from get_vehicle_lock_status."""
     try:
@@ -306,18 +312,22 @@ async def update_lock_status(
         raise click.ClickException(repr(exc)) from exc
     except KamereonResponseException as exc:  # pragma: no cover
         click.echo(f"lock status: {exc.error_details}", err=True)
-    else:
-        items = [
-            ("Lock status", response.lockStatus, None),
-            ("Lock last updated", response.lastUpdateTime, "tzdatetime"),
-        ]
+        return
 
-        for key, value, unit in items:
-            update_status_table(status_table, key, value, unit)
+    if ctx_data["json"]:  # pragma: no cover
+        status_table["lock-status"] = response.raw_data
+        return
+    items = [
+        ("Lock status", response.lockStatus, None),
+        ("Lock last updated", response.lastUpdateTime, "tzdatetime"),
+    ]
+
+    for key, value, unit in items:
+        update_status_table(status_table, key, value, unit)
 
 
 async def update_res_state(
-    vehicle: RenaultVehicle, status_table: Dict[str, Any]
+    vehicle: RenaultVehicle, status_table: Dict[str, Any], ctx_data: Dict[str, Any]
 ) -> None:
     """Update status table from get_vehicle_res_state."""
     try:
@@ -328,38 +338,41 @@ async def update_res_state(
         raise click.ClickException(repr(exc)) from exc
     except KamereonResponseException as exc:  # pragma: no cover
         click.echo(f"res state: {exc.error_details}", err=True)
-    else:
-        items = [
-            ("Engine state", response.details, None),
-        ]
+        return
 
-        for key, value, unit in items:
-            update_status_table(status_table, key, value, unit)
+    if ctx_data["json"]:
+        status_table["res-state"] = response.raw_data
+        return
+    items = [
+        ("Engine state", response.details, None),
+    ]
+
+    for key, value, unit in items:
+        update_status_table(status_table, key, value, unit)
 
 
 async def update_hvac_status(
-    vehicle: RenaultVehicle, status_table: Dict[str, str]
+    vehicle: RenaultVehicle, status_table: Dict[str, Any], ctx_data: Dict[str, Any]
 ) -> None:
     """Update status table from get_vehicle_hvac_status."""
     try:
         if not await vehicle.supports_endpoint("hvac-status"):
             return
-        if not await vehicle.has_contract_for_endpoint(
-            "hvac-status"
-        ):  # pragma: no cover
-            update_status_table(status_table, "HVAC status", "No contract.", None)
-            return
         response = await vehicle.get_hvac_status()
     except QuotaLimitException as exc:  # pragma: no cover
         raise click.ClickException(repr(exc)) from exc
     except KamereonResponseException as exc:  # pragma: no cover
         click.echo(f"hvac-status: {exc.error_details}", err=True)
-    else:
-        items = [
-            ("HVAC status", response.hvacStatus, None),
-            ("HVAC start at", response.nextHvacStartDate, "tzdatetime"),
-            ("External temperature", response.externalTemperature, "°C"),
-        ]
+        return
 
-        for key, value, unit in items:
-            update_status_table(status_table, key, value, unit)
+    if ctx_data["json"]:
+        status_table["hvac-status"] = response.raw_data
+        return
+    items = [
+        ("HVAC status", response.hvacStatus, None),
+        ("HVAC start at", response.nextHvacStartDate, "tzdatetime"),
+        ("External temperature", response.externalTemperature, "°C"),
+    ]
+
+    for key, value, unit in items:
+        update_status_table(status_table, key, value, unit)
